@@ -28,8 +28,6 @@ DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * $Id$
  */
 
 /**
@@ -377,7 +375,7 @@ static void HPRemoveDevice(struct udev_device *dev)
 
 static void HPAddDevice(struct udev_device *dev)
 {
-	int i;
+	int index, a;
 	char *deviceName = NULL;
 	char *fullname = NULL;
 	struct _driverTracker *driver, *classdriver;
@@ -426,9 +424,9 @@ static void HPAddDevice(struct udev_device *dev)
 	}
 
 	/* check for duplicated add */
-	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
+	for (index=0; index<PCSCLITE_MAX_READERS_CONTEXTS; index++)
 	{
-		if (readerTracker[i].fullName && !strcmp(sysname, readerTracker[i].sysname))
+		if (readerTracker[index].fullName && !strcmp(sysname, readerTracker[index].sysname))
 			return;
 	}
 
@@ -440,20 +438,25 @@ static void HPAddDevice(struct udev_device *dev)
 	else
 		bInterfaceNumber = 0;
 
-	asprintf(&deviceName, "usb:%04x/%04x:libudev:%d:%s",
+	a = asprintf(&deviceName, "usb:%04x/%04x:libudev:%d:%s",
 		driver->manuID, driver->productID, bInterfaceNumber, devpath);
+	if (-1 ==  a)
+	{
+		Log1(PCSC_LOG_ERROR, "asprintf() failed");
+		return;
+	}
 
 	/* find a free entry */
-	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
+	for (index=0; index<PCSCLITE_MAX_READERS_CONTEXTS; index++)
 	{
-		if (NULL == readerTracker[i].fullName)
+		if (NULL == readerTracker[index].fullName)
 			break;
 	}
 
-	if (PCSCLITE_MAX_READERS_CONTEXTS == i)
+	if (PCSCLITE_MAX_READERS_CONTEXTS == index)
 	{
 		Log2(PCSC_LOG_ERROR,
-			"Not enough reader entries. Already found %d readers", i);
+			"Not enough reader entries. Already found %d readers", index);
 		return;
 	}
 
@@ -472,7 +475,12 @@ static void HPAddDevice(struct udev_device *dev)
 		char *result;
 
 		/* create a new name */
-		asprintf(&result, "%s [%s]", fullname, sInterfaceName);
+		a = asprintf(&result, "%s [%s]", fullname, sInterfaceName);
+		if (-1 ==  a)
+		{
+			Log1(PCSC_LOG_ERROR, "asprintf() failed");
+			goto exit;
+		}
 
 		free(fullname);
 		fullname = result;
@@ -488,18 +496,23 @@ static void HPAddDevice(struct udev_device *dev)
 			char *result;
 
 			/* create a new name */
-			asprintf(&result, "%s (%s)", fullname, sSerialNumber);
+			a = asprintf(&result, "%s (%s)", fullname, sSerialNumber);
+			if (-1 ==  a)
+			{
+				Log1(PCSC_LOG_ERROR, "asprintf() failed");
+				goto exit;
+			}
 
 			free(fullname);
 			fullname = result;
 		}
 	}
 
-	readerTracker[i].fullName = strdup(fullname);
-	readerTracker[i].devpath = strdup(devpath);
-	readerTracker[i].sysname = strdup(sysname);
+	readerTracker[index].fullName = strdup(fullname);
+	readerTracker[index].devpath = strdup(devpath);
+	readerTracker[index].sysname = strdup(sysname);
 
-	ret = RFAddReader(fullname, PCSCLITE_HP_BASE_PORT + i,
+	ret = RFAddReader(fullname, PCSCLITE_HP_BASE_PORT + index,
 		driver->libraryPath, deviceName);
 	if ((SCARD_S_SUCCESS != ret) && (SCARD_E_UNKNOWN_READER != ret))
 	{
@@ -509,7 +522,7 @@ static void HPAddDevice(struct udev_device *dev)
 		if (classdriver && driver != classdriver)
 		{
 			/* the reader can also be used by the a class driver */
-			ret = RFAddReader(fullname, PCSCLITE_HP_BASE_PORT + i,
+			ret = RFAddReader(fullname, PCSCLITE_HP_BASE_PORT + index,
 				classdriver->libraryPath, deviceName);
 			if ((SCARD_S_SUCCESS != ret) && (SCARD_E_UNKNOWN_READER != ret))
 			{
@@ -524,6 +537,18 @@ static void HPAddDevice(struct udev_device *dev)
 		}
 	}
 
+	if (SCARD_S_SUCCESS != ret)
+	{
+		/* adding the reader failed */
+		free(readerTracker[index].devpath);
+		readerTracker[index].devpath = NULL;
+		free(readerTracker[index].fullName);
+		readerTracker[index].fullName = NULL;
+		free(readerTracker[index].sysname);
+		readerTracker[index].sysname = NULL;
+	}
+
+exit:
 	free(fullname);
 	free(deviceName);
 } /* HPAddDevice */
