@@ -28,8 +28,6 @@ DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * $Id$
  */
 
 /**
@@ -681,6 +679,7 @@ int main(int argc, char **argv)
 			Log2(PCSC_LOG_ERROR, "write() failed: %s", strerror(errno));
 		}
 		close(pipefd[1]);
+		pipefd[1] = -1;
 	}
 
 	SVCServiceRunLoop();
@@ -799,7 +798,7 @@ static void print_version (void)
 	printf("Copyright (C) 1999-2002 by David Corcoran <corcoran@musclecard.com>.\n");
 	printf("Copyright (C) 2001-2011 by Ludovic Rousseau <ludovic.rousseau@free.fr>.\n");
 	printf("Copyright (C) 2003-2004 by Damien Sauveron <sauveron@labri.fr>.\n");
-	printf("Report bugs to <muscle@lists.musclecard.com>.\n");
+	printf("Report bugs to <pcsclite-muscle@lists.alioth.debian.org>.\n");
 
 	printf ("Enabled features:%s\n", PCSCLITE_FEATURES);
 }
