@@ -28,8 +28,6 @@ DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * $Id: winscard.c 7004 2014-10-02 09:26:36Z rousseau $
  */
 
 /**
@@ -120,7 +118,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "eventhandler.h"
 #include "utils.h"
 #include "reader.h"
-#include "strlcpycat.h"
 
 #undef DO_PROFILE
 #ifdef DO_PROFILE
@@ -1429,8 +1426,7 @@ LONG SCardGetAttrib(SCARDHANDLE hCard, DWORD dwAttrId,
 					rv = SCARD_E_INSUFFICIENT_BUFFER;
 				else
 				{
-					(void)strlcpy((char *)pbAttr,
-						rContext->readerState->readerName, len);
+					strcpy((char *)pbAttr, rContext->readerState->readerName);
 					rv = SCARD_S_SUCCESS;
 				}
 				*pcbAttrLen = len;
